Validator function factory for scalar properties. Use it to create functions to be passed as validators for S7 properties.
Arguments
- type
A character specifying the type of scalar property. Possible values are "character" and "boolean".
- allow_null
A logical indicating whether NULL is an allowed value for the property. When this is used, should be accompanied by defining the property's
classargument to the union of NULL and a targeted class, and using NULL as the property'sdefaultvalue.